<?php
namespace FlyingProxy;

class Settings
{
  public static function init()
  {
    add_action('admin_menu', ['FlyingProxy\Settings', 'add_new_menu_items']);
    add_action('admin_init', ['FlyingProxy\Settings', 'display_options']);
    add_filter('plugin_action_links_' . FLYINGPROXY_FILE, ['FlyingProxy\Settings', 'add_shortcut']);
  }

  // Add menu: Settings -> FlyingProxy
  public static function add_new_menu_items()
  {
    add_options_page('FlyingProxy', 'FlyingProxy', 'manage_options', 'flyingproxy', [
      'FlyingProxy\Settings',
      'flyingproxy_settings_page',
    ]);
  }

  // View of settings page
  public static function flyingproxy_settings_page()
  {
    ?>
<div class="wrap">
    <h1>FlyingProxy settings</h1>
    <form method="post" action="options.php">
        <?php
        //add_settings_section callback is displayed here. For every new section we need to call settings_fields.
        settings_fields('header_section');

        // all the add_settings_field callbacks is displayed here
        do_settings_sections('flyingproxy-settings');

        // Add the submit button to serialize the options
        submit_button();?>
    </form>
</div>
<?php
  }

  public static function display_options()
  {
    //section name, display name, callback to print description of section, page to which section is attached.
    add_settings_section(
      'header_section',
      '',
      ['FlyingProxy\Settings', 'description'],
      'flyingproxy-settings'
    );

    //setting name, display name, callback to print form element, page in which field is displayed, section to which it belongs.
    //last field section is optional.
    add_settings_field(
      'flyingproxy_api_key',
      'API key',
      ['FlyingProxy\Settings', 'display_api_key_input'],
      'flyingproxy-settings',
      'header_section'
    );

    //section name, form element name, callback for sanitization
    register_setting('header_section', 'flyingproxy_api_key');
  }

  public static function description()
  {
    $domain = $_SERVER['SERVER_NAME'];
    $url = "https://app.flyingproxy.com/sites/$domain/settings";
    echo "<p>You can grab API key from your FlyingProxy site <a href=$url target=_blank>settings</a></p>";
  }

  // Form element for API key
  public static function display_api_key_input()
  {
    $api_key = get_option('flyingproxy_api_key');
    echo "<input type=password name=flyingproxy_api_key id=flyingproxy_api_key value='$api_key'/>";
  }

  // Add a link to settings in plugins list
  public static function add_shortcut($links)
  {
    $settings_url = admin_url('options-general.php?page=flyingproxy');
    $settings_link = "<a href='$settings_url'> Settings</a>";

    $domain = $_SERVER['SERVER_NAME'];
    $app_link = "<a href=https://app.flyingproxy.com/sites/$domain/dashboard target=_blank>Open App</a>";

    array_push($links, $settings_link, $app_link);

    return $links;
  }
}